==> python_plisio-2.0.1.tar.gz: python_plisio-2.0.1/README.md <==
# Python-Plisio-SDK

[![python](https://img.shields.io/badge/Python-%5E3.8.1-3776AB.svg?style=flat&logo=python&logoColor=tellow)](https://www.python.org)
[![Codacy Badge](https://app.codacy.com/project/badge/Grade/152926ced23a45c6abb55af6884f890f)](https://app.codacy.com/gh/amiwrpremium/python-plisio/dashboard?utm_source=gh&utm_medium=referral&utm_content=&utm_campaign=Badge_grade)
![GitHub](https://img.shields.io/github/license/amiwrpremium/python-plisio)
[![Documentation Status](https://readthedocs.org/projects/python-plisio/badge/?version=latest)](https://python-plisio.readthedocs.io/en/latest/?badge=latest)
[![Documentation Status](https://img.shields.io/badge/docs-mkdocs%20material-blue.svg?style=flat)](https://squidfunk.github.io/mkdocs-material/)
[![pydocstyle](https://img.shields.io/badge/pydocstyle-enabled-AD4CD3)](http://www.pydocstyle.org/en/stable/)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/pre-commit/pre-commit)
[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/amiwrpremium/python-plisio/master.svg)](https://results.pre-commit.ci/latest/github/amiwrpremium/python-plisio/master)
![PyPI](https://img.shields.io/pypi/v/python-plisio?color=blue)
![GitHub Workflow Status](https://img.shields.io/github/actions/workflow/status/amiwrpremium/python-plisio/publish.yml?label=publish)

## About

[Plisio](https://plisio.net/) is a payment gateway for accepting
payments in cryptocurrencies. Plisio enables your customers to pay with
15+ cryptocurrencies, including Bitcoin, Ethereum, Litecoin, Dash, etc.

**I'm in no way affiliated with Plisio and this is not an official SDK.**

## Installation

Install using `pip`
> $ pip install python-plisio

Install from `git`
> pip install git+https://github.com/amiwrpremium/python-plisio.git

## Usage

See [examples](docs/examples) for more usage examples.

## Documentation

See [documentation](https://python-plisio.readthedocs.io/en/latest/).

## License

See [LICENSE](LICENSE).

## Disclaimer

This is not an official SDK, and I am in no way affiliated with Plisio.

==> python_plisio-2.0.2.tar.gz: python_plisio-2.0.2/README.md <==
# Python-Plisio-SDK

[![Poetry](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/johnthagen/poetry/poetry-badge/assets/badge/v0.json)](https://python-poetry.org/)
[![python](https://img.shields.io/badge/Python-%5E3.8.1-3776AB.svg?style=flat&logo=python&logoColor=tellow)](https://www.python.org)
![PyPI](https://img.shields.io/pypi/v/python-plisio?color=blue)
[![Codacy Badge](https://app.codacy.com/project/badge/Grade/152926ced23a45c6abb55af6884f890f)](https://app.codacy.com/gh/amiwrpremium/python-plisio/dashboard?utm_source=gh&utm_medium=referral&utm_content=&utm_campaign=Badge_grade)
![GitHub](https://img.shields.io/github/license/amiwrpremium/python-plisio)
[![Documentation Status](https://readthedocs.org/projects/python-plisio/badge/?version=latest)](https://python-plisio.readthedocs.io/en/latest/?badge=latest)
[![Documentation Status](https://img.shields.io/badge/docs-mkdocs%20material-blue.svg?style=flat)](https://squidfunk.github.io/mkdocs-material/)
[![pydocstyle](https://img.shields.io/badge/pydocstyle-enabled-AD4CD3)](http://www.pydocstyle.org/en/stable/)
[![Checked with mypy](http://www.mypy-lang.org/static/mypy_badge.svg)](http://mypy-lang.org/)
[![linting: pylint](https://img.shields.io/badge/linting-pylint-yellowgreen)](https://github.com/pylint-dev/pylint)
[![Flake8 Status](./reports/flake8/flake8-badge.svg?dummy=8484744)](./reports/flake8/index.html)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/pre-commit/pre-commit)
[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/amiwrpremium/python-plisio/master.svg)](https://results.pre-commit.ci/latest/github/amiwrpremium/python-plisio/master)
![GitHub Workflow Status](https://img.shields.io/github/actions/workflow/status/amiwrpremium/python-plisio/publish.yml?label=publish)

## About

[Plisio](https://plisio.net/) is a payment gateway for accepting
payments in cryptocurrencies. Plisio enables your customers to pay with
15+ cryptocurrencies, including Bitcoin, Ethereum, Litecoin, Dash, etc.

**I'm in no way affiliated with Plisio and this is not an official SDK.**

## Installation

Install using `pip` from [PyPI](https://pypi.org/project/python-plisio/):
> pip install python-plisio

Install from `git`
> pip install git+https://github.com/amiwrpremium/python-plisio.git

## Usage

See [examples](https://python-plisio.readthedocs.io/en/latest/examples/) for more usage examples.

## Documentation

See [documentation](https://python-plisio.readthedocs.io/en/latest/).

## License

See [LICENSE](LICENSE).

## Disclaimer

This is not an official SDK, and I am in no way affiliated with Plisio.
